<?php
function _sendMail(&$tof,$vars) {
	require_once("actions/mail.php");
	sendMail(
		$tof,
		$vars['Groups'],
		$vars['MailSubject'],
		$vars['MailBody'],
		$tof['ExcludeSender']);
}
?>